from ._yaxis import YAxisValidator
from ._visible import VisibleValidator
from ._thickness import ThicknessValidator
from ._range import RangeValidator
from ._borderwidth import BorderwidthValidator
from ._bordercolor import BordercolorValidator
from ._bgcolor import BgcolorValidator
from ._autorange import AutorangeValidator
