from ._yaxes import YaxesValidator
from ._xaxes import XaxesValidator
from ._visible import VisibleValidator
from ._unselected import UnselectedValidator
from ._uid import UidValidator
from ._textsrc import TextsrcValidator
from ._text import TextValidator
from ._stream import StreamValidator
from ._showupperhalf import ShowupperhalfValidator
from ._showlowerhalf import ShowlowerhalfValidator
from ._showlegend import ShowlegendValidator
from ._selectedpoints import SelectedpointsValidator
from ._selected import SelectedValidator
from ._opacity import OpacityValidator
from ._name import NameValidator
from ._marker import MarkerValidator
from ._legendgroup import LegendgroupValidator
from ._idssrc import IdssrcValidator
from ._ids import IdsValidator
from ._hoverlabel import HoverlabelValidator
from ._hoverinfosrc import HoverinfosrcValidator
from ._hoverinfo import HoverinfoValidator
from ._dimensiondefaults import DimensionValidator
from ._dimensions import DimensionsValidator
from ._diagonal import DiagonalValidator
from ._customdatasrc import CustomdatasrcValidator
from ._customdata import CustomdataValidator
